@@ -2,7 +2,7 @@ import logging
 
 import pyclipper as pcl
 
-from src.map_analyser import maplib as ml
+from map_analyser import maplib as ml
 
 from .util import (intersects, paths_to_areas, paths_to_holes,
                    poly_tree_to_areas)
