@@ -1,6 +1,6 @@
 import numpy as np
 
-from src.map_analyser import maplib as ml
+from map_analyser import maplib as ml
 
 EPSILON = 0.1
 
@@ -52,21 +52,6 @@ def dot(a, b):
     return a.x * b.x + a.y * b.y
 
 
-# # unused old functions:
-# def area_orientation(area):
-#     prace = area.coords_zipped
-#     return orientation(prace[0], prace[1], prace[2])
-#
-#
-# def coords_orientation(prace):
-#     return orientation(prace[0], prace[1], prace[2])
-#
-#
-# def debug_coords_orientation(prace):
-#     a,b,c = prace[0], prace[1], prace[2]
-#     return cross(b-a, b-c)
-
-
 def convex_orientation(a, b, c):
     return cross(b - a, b - c) >= 0
 
